==> ejc-bfyjerp-impl-3.0.0-20241227.014805-87-sources.jar: com/ejianc/business/asset/bean/PayReimburseDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 资产管理-费用报销子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_asset_pay_reimburse_detail")
public class PayReimburseDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="payapply_id")
    private Long payapplyId; // 付款申请单主键
    @TableField(value="fee_type")
    private Long feeType; // 费用类别
    @TableField(value="fee_type_name")
    private String feeTypeName; // 费用类别名称
    @TableField(value="fee_tax_mny")
    private BigDecimal feeTaxMny; // 费用金额
    @TableField(value="fee_happen_date")
    private Date feeHappenDate; // 费用发生日期
    @TableField(value="subject_id")
    private Long subjectId; // 成本科目主键
    @TableField(value="subject_name")
    private String subjectName; // 成本科目名称
    @TableField(value="fee_memo")
    private String feeMemo; // 备注
    
    
    

    public Long getPayapplyId() {
        return payapplyId;
    }

    public void setPayapplyId(Long payapplyId) {
        this.payapplyId = payapplyId;
    }
    public Long getFeeType() {
        return feeType;
    }

    public void setFeeType(Long feeType) {
        this.feeType = feeType;
    }
    public String getFeeTypeName() {
        return feeTypeName;
    }

    public void setFeeTypeName(String feeTypeName) {
        this.feeTypeName = feeTypeName;
    }
    public BigDecimal getFeeTaxMny() {
        return feeTaxMny;
    }

    public void setFeeTaxMny(BigDecimal feeTaxMny) {
        this.feeTaxMny = feeTaxMny;
    }
    public Date getFeeHappenDate() {
        return feeHappenDate;
    }

    public void setFeeHappenDate(Date feeHappenDate) {
        this.feeHappenDate = feeHappenDate;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public String getFeeMemo() {
        return feeMemo;
    }

    public void setFeeMemo(String feeMemo) {
        this.feeMemo = feeMemo;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250522.094913-219-sources.jar: com/ejianc/business/asset/bean/PayReimburseDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 资产管理-费用报销子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_asset_pay_reimburse_detail")
public class PayReimburseDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="payapply_id")
    private Long payapplyId; // 付款申请单主键
    @TableField(value="fee_type")
    private Long feeType; // 费用类别
    @TableField(value="fee_type_name")
    private String feeTypeName; // 费用类别名称
    @TableField(value="fee_tax_mny")
    private BigDecimal feeTaxMny; // 费用金额
    @TableField(value="fee_happen_date")
    private Date feeHappenDate; // 费用发生日期
    @TableField(value="subject_id")
    private Long subjectId; // 成本科目主键
    @TableField(value="subject_name")
    private String subjectName; // 成本科目名称
    @TableField(value="fee_memo")
    private String feeMemo; // 备注

    @TableField(value="fee_type_cost_type")
    private Integer feeTypeCostType; // 费用报销档案-成本费用类型
    @TableField(value="fee_type_cost_type_name")
    private String feeTypeCostTypeName; // 费用报销档案-成本费用类型

    public Integer getFeeTypeCostType() {
        return feeTypeCostType;
    }

    public void setFeeTypeCostType(Integer feeTypeCostType) {
        this.feeTypeCostType = feeTypeCostType;
    }

    public String getFeeTypeCostTypeName() {
        return feeTypeCostTypeName;
    }

    public void setFeeTypeCostTypeName(String feeTypeCostTypeName) {
        this.feeTypeCostTypeName = feeTypeCostTypeName;
    }

    public Long getPayapplyId() {
        return payapplyId;
    }

    public void setPayapplyId(Long payapplyId) {
        this.payapplyId = payapplyId;
    }
    public Long getFeeType() {
        return feeType;
    }

    public void setFeeType(Long feeType) {
        this.feeType = feeType;
    }
    public String getFeeTypeName() {
        return feeTypeName;
    }

    public void setFeeTypeName(String feeTypeName) {
        this.feeTypeName = feeTypeName;
    }
    public BigDecimal getFeeTaxMny() {
        return feeTaxMny;
    }

    public void setFeeTaxMny(BigDecimal feeTaxMny) {
        this.feeTaxMny = feeTaxMny;
    }
    public Date getFeeHappenDate() {
        return feeHappenDate;
    }

    public void setFeeHappenDate(Date feeHappenDate) {
        this.feeHappenDate = feeHappenDate;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public String getFeeMemo() {
        return feeMemo;
    }

    public void setFeeMemo(String feeMemo) {
        this.feeMemo = feeMemo;
    }
    
}
